@@ -1,17 +1,10 @@
 import nonebot
-from pathlib import Path
 from typing import List
-from nonebot import run
 from nonebot.rule import Rule
 from nonebot.plugin import on_message, on_regex
 from nonebot.adapters.onebot.v11 import Bot, Event, Message, MessageSegment, GroupMessageEvent
 import aiohttp, re, os, random, cv2, asyncio, base64, json
 
-_sub_plugins = set()
-_sub_plugins |= nonebot.load_plugins(
-    str((Path(__file__).parent / "plugins").
-        resolve()))
-
 global_config = nonebot.get_driver().config
 config = global_config.dict()
 
@@ -19,32 +12,38 @@ imgRoot = config.get('imgroot') if config.get('imgroot') else f"{os.environ['HOM
 proxy_aiohttp = config.get('aiohttp') if config.get('aiohttp') else ""
 pixiv_cookies = config.get('pixiv_cookies') if config.get('pixiv_cookies') else ""
 ffmpeg = config.get('ffmpeg') if config.get('ffmpeg') else "/usr/bin/ffmpeg"
-pixiv_r18 = config.get('pixiv_r18') if config.get('pixiv_r18') else "True"
-pixiv_r18 = eval(pixiv_r18)
-
-pathHome = imgRoot + "QQbotFiles/pixiv"
-if not os.path.exists(pathHome):
-    os.makedirs(pathHome)
-
-pathZipHome = imgRoot + "QQbotFiles/pixivZip"
-if not os.path.exists(pathZipHome):
-    os.makedirs(pathZipHome)
-
 headersCook = {
     'referer': 'https://www.pixiv.net',
     'user-agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.163 Safari/537.36',
 }
-
 if pixiv_cookies:
     headersCook['cookie'] = pixiv_cookies
 
+pixiv_r18 = config.get('pixiv_r18')
+if not pixiv_r18:
+    pixiv_r18 = True
+if pixiv_r18 and ( pixiv_r18 == 'True' or pixiv_r18 == 'False'):
+    pixiv_r18 = eval(pixiv_r18)
+elif pixiv_r18:
+    try:
+        pixiv_r18 = eval(pixiv_r18)
+        if not isinstance(pixiv_r18,list):
+            print("配置错误！！pixiv_r18应该是列表")
+        else:
+            for x in pixiv_r18:
+                if not(isinstance(x,int) or (isinstance(x,str) and str(x).isdigit())):
+                    print("配置错误！！pixiv_r18中应该是int类型或者str的数值类型")
+    except:
+        print("配置错误！！")
+    
 
-async def checkConfig(bot: Bot, event: Event) -> bool:
-    if not pixiv_cookies:
-        await bot.send(event=event, message="pixiv_cookies未配置!!")
-        return False
-    return True
+pathHome = f"{imgRoot}QQbotFiles/pixiv"
+if not os.path.exists(pathHome):
+    os.makedirs(pathHome)
 
+pathZipHome = f"{imgRoot}QQbotFiles/pixivZip"
+if not os.path.exists(pathZipHome):
+    os.makedirs(pathZipHome)
 
 def isPixivURL() -> Rule:
     async def isPixivURL_(bot: "Bot", event: "Event") -> bool:
@@ -60,16 +59,29 @@ def isPixivURL() -> Rule:
 
 pixivURL = on_message(rule=isPixivURL())
 
+async def check_r18(bot: Bot,event : Event, pid: str)->bool:
+    print("R18检查ing")
+    if not await pan_R18(pid):
+        return True
+    if isinstance(pixiv_r18,bool):
+        if (not pixiv_r18):
+            await bot.send(event=event,message="不支持R18，请修改配置后操作！")
+            return False
+    elif isinstance(pixiv_r18, list):
+        if isinstance(event, GroupMessageEvent):
+            flag = any(True if str(x) == str(event.group_id) else False for x in pixiv_r18)
+            if not flag:
+                await bot.send(event=event,message="不支持R18，请修改配置后操作！")
+            return flag
+
+    return True
 
 @pixivURL.handle()
 async def pixivURL(bot: Bot, event: Event):
-    if not await checkConfig(bot, event):
-        return
     pid = re.findall("https://www.pixiv.net/artworks/(\d+)|illust_id=(\d+)", str(event.get_message()))
     if pid:
         pid = [x for x in pid[0] if x][0]
-        if (not pixiv_r18) and  await pan_R18(pid):
-            await bot.send(event=event,message="不支持R18，请修改配置后操作！")
+        if not check_r18(bot,event,pid):
             return
         xx = (await checkGIF(pid))
         if xx != "NO":
@@ -83,13 +95,12 @@ pixiv = on_regex(pattern="^pixiv\ ")
 
 @pixiv.handle()
 async def pixiv_rev(bot: Bot, event: Event):
-    if not await checkConfig(bot, event):
-        return
     pid = str(event.message).strip()[6:].strip()
-    if (not pixiv_r18) and  await pan_R18(pid):
-        await bot.send(event=event,message="不支持R18，请修改配置后操作！")
+    print("?????????????????????")
+    if not await check_r18(bot,event,pid):
         return
     xx = (await checkGIF(pid))
+    print("动图判断")
     if xx != "NO":
         await GIF_send(xx, pid, event, bot)
     else:
@@ -100,40 +111,52 @@ async def fetch(session, url, name):
     print("发送请求：", url)
     async with session.get(url=url, headers=headersCook, proxy=proxy_aiohttp) as response:
         # async with session.get(url=url, headers=headers) as response:
-        code = response.status
-        if code == 200:
-            content = await response.content.read()
-            with open(f"{imgRoot}QQbotFiles/pixiv/" + name, mode='wb') as f:
-                f.write(content)
-            return True
-        return False
+        async def fetch(session, url, name):
+            print("发送请求：", url)
+            async with session.get(url=url, headers=headersCook, proxy=proxy_aiohttp) as response:
+                # async with session.get(url=url, headers=headers) as response:
+                code = response.status
+                if code == 200:
+                    content = await response.content.read()
+                    with open(f"{imgRoot}QQbotFiles/pixiv/" + name, mode='wb') as f:
+                        f.write(content)
+                    return True
+                return False
 
 
 async def main(PID):
-    url = f"https://www.pixiv.net/artworks/{PID}"
+    # url = f"https://www.pixiv.net/artworks/{PID}"
+    url = f"https://api.obfs.dev/api/pixiv/illust?id={PID}"
     async with aiohttp.ClientSession() as session:
         x = await session.get(url=url, headers=headersCook, proxy=proxy_aiohttp)
-        # x = await session.get(url=url, headers=headers)
         content = await x.content.read()
-        down_url = re.findall('"original":"(.*?)\.(png|jpg|jepg)"', content.decode())
-        if not down_url:
-            return ""
-        url = '.'.join(down_url[0])
+        content = json.loads(content)
+        # down_url = re.findall('"original":"(.*?)\.(png|jpg|jepg)"', content.json())
+        if content.get('error'):
+            return
+        url = content.get('illust').get('meta_single_page')
+        if url:
+            url = url.get('original_image_url')
+        else:
+            url = content.get('illust').get('meta_pages')[0].get('image_urls').get('original')
+        print(url)
         name = url[url.rfind("/") + 1:]
-        num = 1
+        hou_zhui = name.split(".")[1]
+        print(name)
+        print(hou_zhui)
         names = []
+        num = 1
         if os.path.exists(f"{imgRoot}QQbotFiles/pixiv/" + name):
-            hou = down_url[0][1]
             while os.path.exists(f"{imgRoot}QQbotFiles/pixiv/" + name) and num <= 6:
                 names.append(name)
-                newstr = f"_p{num}.{hou}"
+                newstr = f"_p{num}.{hou_zhui}"
                 num += 1
                 name = re.sub("_p(\d+)\.(png|jpg|jepg)", newstr, name)
+                print(name)
         else:
-            hou = down_url[0][1]
             while (await fetch(session=session, url=url, name=name) and num <= 6):
                 names.append(name)
-                newstr = f"_p{num}.{hou}"
+                newstr = f"_p{num}.{hou_zhui}"
                 num += 1
                 url = re.sub("_p(\d+)\.(png|jpg|jepg)", newstr, url)
                 name = url[url.rfind("/") + 1:]
@@ -158,8 +181,6 @@ pixivRank = on_regex(pattern="^pixivRank\ ")
 
 @pixivRank.handle()
 async def pixiv_rev(bot: Bot, event: Event):
-    if not await checkConfig(bot, event):
-        return
     info = str(event.message).strip()[10:].strip()
     dic = {
         "1": "day",
@@ -229,7 +250,24 @@ async def send(pid: str, event: Event, bot: Bot):
                         await yasuo(path)
                     await bot.send(event=event, message=MessageSegment.image(await base64_path(path)))
             except:
-                await bot.send(event=event, message="查询失败, 帐号有可能发生风控，请检查!!!")
+                try:
+                    await bot.send(event=event, message="一张一张发送图片也风控了，尝试修改md5值再发送")
+                    for name in names:
+                        path = f"{imgRoot}QQbotFiles/pixiv/{name}"
+                        os.system(f"echo '1' >> {path}")
+                    msg=None
+                    for name in names:
+                        path = f"{imgRoot}QQbotFiles/pixiv/{name}"
+                        size = os.path.getsize(path)
+                        if size // 1024 // 1024 >= 10:
+                            await yasuo(path)
+                        msg += MessageSegment.image(await base64_path(path))
+                    if isinstance(event, GroupMessageEvent):
+                        await send_forward_msg_group(bot, event, 'qqbot', msg)
+                    else:
+                        await bot.send(event=event, message=msg)
+                except:
+                    await bot.send(event=event, message="查询失败, 帐号有可能发生风控，请检查!!!")
 
 
 async def yasuo(path):
@@ -243,8 +281,11 @@ async def yasuo(path):
 async def checkGIF(pid: str) -> str:
     url = f'https://www.pixiv.net/ajax/illust/{pid}/ugoira_meta'
     async with aiohttp.ClientSession() as session:
+        if pixiv_cookies:
+            headersCook['cookie'] = pixiv_cookies
         x = await session.get(url=url, headers=headersCook, proxy=proxy_aiohttp)
         content = await x.json()
+        print(content)
         if content['error']:
             return "NO"
         return content['body']['originalSrc']
@@ -326,13 +367,16 @@ async def send_forward_msg_group(
 
 async def pan_R18(PID):
     print("判断是不是R18")
-    url = f"https://www.pixiv.net/artworks/{PID}"
+    url = f"https://api.obfs.dev/api/pixiv/illust?id={PID}"
     async with aiohttp.ClientSession() as session:
-        x = await session.get(url=url, headers=headersCook,proxy=proxy_aiohttp)
+        x = await session.get(url=url, headers=headersCook, proxy=proxy_aiohttp)
         content = await x.content.read()
-        tags = re.findall('\"tags\"\:\[(.*?)\]',content.decode())[0]
-        print(tags)
-        if 'R-18' in tags:
+        content = json.loads(content)
+        if content.get('error'):
+            return False
+        tag = content['illust']['tags'][0]['name']
+        print("tag: "+tag)
+        if tag == 'R-18':
             return True
         else:
             return False
@@ -341,12 +385,6 @@ async def pan_R18(PID):
 
 
 # @pixivS.handle()
-# async def pixivS_rev(bot: Bot, event: Event):
-    # if not await checkConfig(bot, event):
-        # return
-    # pid = ""
-    # key = str(event.message).strip()[2:].strip() + " 100users入り"
-    # async with aiohttp.ClientSession() as session:
         # x = await session.get(url="https://www.pixiv.net/ajax/search/artworks/"+str(key), headers=headersCook, proxy=proxy_aiohttp)
         # # x = await session.get(url=url, headers=headers)
         # content = await x.content.read()
